import { ComponentTypes, MessageFlags, Shard } from "oceanic.js";
import { client } from ".";
import { Constants } from "./Constants";
import { Header, Divider, generateUserComponent } from "./cv2";
import { db } from "./database";
import { selfappReq } from "./selfappReq";

export async function setupJoinRequestHandler(shard: Shard) {
	shard.ws?.on("message", async (d) => {
		const data = JSON.parse(d.toString("utf8"));
		if (!data.t) return;
		if (data.t.startsWith("GUILD_JOIN_REQUEST")) {
			const applicationData = data.d;
			switch (data.t) {
				case "GUILD_JOIN_REQUEST_UPDATE": {
					switch (applicationData.status) {
						case "SUBMITTED": {
							const pendingMsg =
								await client.rest.channels.createMessage(
									Constants.PENDING_CHANNEL_ID,
									{
										content: "Placeholder"
									}
								);
							await db.run(
								"INSERT INTO applications (id, user_id, status, message_id, channel_id) VALUES (?, ?, 0, ?, ?)",
								applicationData.request.id,
								applicationData.request.user_id,
								pendingMsg.id,
								pendingMsg.channelID
							);

							break;
						}
					}
					break;
				}
				case "GUILD_JOIN_REQUEST_DELETE": {
					const application = await db.get(
						"SELECT * FROM applications WHERE id=?",
						applicationData.id
					);
					if (application) {
						await db.run(
							"DELETE FROM applications WHERE id=?",
							applicationData.id
						);
						await client.rest.channels.deleteMessage(
							application.channel_id,
							application.message_id
						);
					}
					await client.rest.channels.createMessage(
						Constants.REJECTION_CHANNEL_ID,
						{
							flags: MessageFlags.IS_COMPONENTS_V2,
							components: [
								{
									type: ComponentTypes.CONTAINER,
									accentColor: 0xffaaaa,
									components: [
										Header("Join request withdrawn", 2),
										Divider,
										await generateUserComponent(
											applicationData.user_id
										),
										Divider,
										Header("Application", 3),
										application
											? {
													type: ComponentTypes.TEXT_DISPLAY,
													content: "User has applied"
											  }
											: {
													type: ComponentTypes.TEXT_DISPLAY,
													content:
														"User has never applied"
											  }
									]
								}
							]
						}
					);
					break;
				}
			}
		}
	});
}
